@@ -34,15 +34,14 @@
 #include "orbitcpp/idl-compiler/types/IDLAttribAccessor.h"
 
 #include <iostream>
-#include <sstream>
 
 
 // IDLPassSkels --------------------------------------------------------------
 void 
 IDLPassSkels::runPass() {
 	m_header
-	<< indent << "#ifndef __ORBITCPP_IDL_" << idlUpper(m_state.m_basename) << "_SKELS" << endl
-	<< indent << "#define __ORBITCPP_IDL_" << idlUpper(m_state.m_basename) << "_SKELS" << endl
+	<< indent << "#ifndef ORBITCPP_IDL_" << idlUpper(m_state.m_basename) << "_SKELS" << endl
+	<< indent << "#define ORBITCPP_IDL_" << idlUpper(m_state.m_basename) << "_SKELS" << endl
 	<< indent << "#include \"" << m_state.m_basename << IDL_CPP_STUB_HEADER_EXT"\"" << endl
 	<< indent << endl << endl
 	<< indent << "// Skeleton declaration --------------------------------" << endl
@@ -450,7 +449,7 @@ IDLPassSkels::doInterfaceFinalizer (IDLInterface &iface)
 		 <<  "::CORBA_Environment *ev)" << endl
 		 << mod_indent++ << "{" << endl;
 
-	m_module << mod_indent << "//Call C __fini():" << endl
+	m_module << mod_indent << "//Call C _fini():" << endl
 		 << mod_indent << IDL_IMPL_C_NS_NOTUSED
 		 << iface.get_c_poa_typename () << "__fini (servant, ev);" << endl << endl;
 	
@@ -497,7 +496,7 @@ IDLPassSkels::doInterfaceDerive(IDLInterface &iface) {
 		for (IDLInterface::BaseList::const_iterator i = iface.m_bases.begin ();
 		     i != iface.m_bases.end (); i++)
 		{
-			m_header << ", public virtual " << (*i)->get_cpp_poa_identifier ();
+			m_header << ", public virtual " << (*i)->get_cpp_poa_typename ();
 		}
 	} else {
 		m_header << ", public virtual "
@@ -548,7 +547,7 @@ IDLPassSkels::doInterfaceDerive(IDLInterface &iface) {
 		 << mod_indent << "m_target.m_cppimpl = this;" << endl
 		 << endl;
 	
-	m_module << mod_indent << "//Call __init(), passing our \"derived\" C Servant:" << endl
+	m_module << mod_indent << "//Call _init(), passing our \"derived\" C Servant:" << endl
 		 << mod_indent << IDL_IMPL_NS "::CEnvironment ev;" << endl
 		 << mod_indent << IDL_IMPL_C_NS_NOTUSED << iface.get_c_poa_typename ()
 		 << "__init (&m_target, ev._orbitcpp_cobj ());" << endl
@@ -580,17 +579,10 @@ IDLPassSkels::doInterfaceDerive(IDLInterface &iface) {
 		 << mod_indent++ << "{" << endl;
 
 	m_module << mod_indent << "PortableServer::POA_var rootPOA = _default_POA ();" << endl << endl;
-	m_module << mod_indent << "static bool activated = false;" << endl;
-	m_module << mod_indent << "PortableServer::ObjectId_var oid = "
-		 << "activated ? rootPOA->servant_to_id (this) : rootPOA->activate_object (this);" << endl;
-	m_module << mod_indent << "activated = true;" << endl << endl;
 	
-	m_module << mod_indent << "CORBA::Object_ptr object = rootPOA->id_to_reference (oid);" << endl;
-	m_module << mod_indent << iface.get_cpp_typename_ptr () << " pDerived = "
+	m_module << mod_indent << "CORBA::Object_var object = rootPOA->servant_to_reference (this);" << endl;
+	m_module << mod_indent << "return "
 		 << stub_name << "::_orbitcpp_wrap (object->_orbitcpp_cobj (), true);" << endl;
-	m_module << mod_indent << "CORBA::release (object);" << endl
-		 << mod_indent << "object = 0;" << endl;
-	m_module << mod_indent << "return pDerived;" << endl;
 	m_module << --mod_indent << "}" << endl << endl;
 
 	
