@@ -70,6 +70,8 @@ protected:
 	void doNative(IDL_tree node,IDLScope &scope);
 	void doConstant(IDL_tree node,IDLScope &scope);
 
+	void doForwardDcl(IDLInterface &iface);
+	void doForwardDcl(IDL_tree node, IDLScope &scope);
 	void doInterface(IDL_tree node,IDLScope &scope);
 	void doMember(IDLMember &member);
 	void doAttribute(IDL_tree node,IDLScope &scope);
@@ -92,12 +94,14 @@ protected:
 	void struct_create_typedefs   (const IDLStruct &strct);
 	void struct_create_any        (const IDLStruct &strct);
 
-	void union_create_internal   (const IDLUnion &un);
-	void union_create_discr      (const IDLUnion &un);
-	void union_create_members    (const IDLUnion &un);
-	void union_create_converters (const IDLUnion &un);
-	void union_create_typedefs   (const IDLUnion &un);
-	void union_create_any        (const IDLUnion &un);
+	void union_create_internal    (const IDLUnion &un);
+	void union_create_constructor (const IDLUnion &un);
+	void union_create_copier      (const IDLUnion &un);
+	void union_create_discr       (const IDLUnion &un);
+	void union_create_members     (const IDLUnion &un);
+	void union_create_converters  (const IDLUnion &un);
+	void union_create_typedefs    (const IDLUnion &un);
+	void union_create_any         (const IDLUnion &un);
 
 	void exception_create_members      (const IDLException &ex);
 	void exception_create_constructors (const IDLException &ex);
