@@ -26,26 +26,27 @@
 
 #include "IDLBoolean.h"
 
-string
+std::string
 IDLBoolean::get_fixed_c_typename () const
 {
 	return "CORBA_boolean";
 }
 
-string
+std::string
 IDLBoolean::get_fixed_cpp_typename () const
 {
 	return IDL_CORBA_NS "::Boolean";
 }
 
-string
-IDLBoolean::getDefaultValue(set<string> const &labels) const
+std::string
+IDLBoolean::get_default_value (std::set<std::string> const &labels) const
 {
-	string val = "";
-	if(labels.find("1") == labels.end()){
-		val="1";
-	} else if(labels.find("0") == labels.end()){
+	std::string val = "";
+
+	if (labels.find ("1") == labels.end())
+		val = "1";
+	else if (labels.find ("0") == labels.end ())
 		val="0";
-	}
+
 	return val;
 }
