@@ -213,9 +213,6 @@ namespace CORBA {
 		_orbitcpp::release_guarded((CORBA_TypeCode)o);
 	}
 	
-	Boolean is_nil(Object_ptr o);
-
-	
 	extern TypeCode_ptr _tc_null;
 	extern TypeCode_ptr _tc_void;
 	extern TypeCode_ptr _tc_short;
@@ -239,5 +236,12 @@ namespace CORBA {
 	extern TypeCode_ptr _tc_wstring;
 }
 
+namespace _orbitcpp {
+	// Return cobj if TypeCode_ptr is not nil.
+	CORBA_TypeCode cobj_guarded(CORBA::TypeCode_ptr);
+	// Return a duplicate of cobj if TypeCode_ptr is not nil.
+	CORBA_TypeCode duplicate_cobj_guarded(CORBA::TypeCode_ptr);
+}
+
 
 #endif		/* ORBITCPP_TYPECODE_HH */
